@@ -69,19 +69,11 @@ class CaptureStatus(IntEnum):
     ONGOING = 2
 
 
-class CaptureResponse(TypedDict, total=False):
+class CaptureResponse(PlaywrightCaptureResponse, TypedDict, total=False):
     '''A capture made by Lacus. With the base64 encoded image and downloaded file decoded to bytes.'''
 
     status: int
-    last_redirected_url: str
-    har: Optional[Dict[str, Any]]
-    cookies: Optional[List[Dict[str, str]]]
-    error: Optional[str]
-    html: Optional[str]
-    png: Optional[bytes]
-    downloaded_filename: Optional[str]
-    downloaded_file: Optional[bytes]
-    children: Optional[List[Any]]
+    runtime: Optional[float]
 
 
 class CaptureResponseJson(TypedDict, total=False):
@@ -97,6 +89,7 @@ class CaptureResponseJson(TypedDict, total=False):
     downloaded_filename: Optional[str]
     downloaded_file: Optional[str]
     children: Optional[List[Any]]
+    runtime: Optional[float]
 
 
 class CaptureSettings(TypedDict, total=False):
@@ -146,6 +139,10 @@ class LacusCore():
         self.only_global_lookups = only_global_lookups
         self.max_retries = max_retries
 
+        # NOTE: clear old ongoing captures queue in case of need
+        if self.redis.type('lacus:ongoing') in ['set', b'set']:
+            self.redis.delete('lacus:ongoing')
+
     def check_redis_up(self) -> bool:
         """Check if redis is reachable"""
         return bool(self.redis.ping())
@@ -375,7 +372,7 @@ class LacusCore():
                             'document', 'browser', 'device_name', 'user_agent', 'proxy',
                             'general_timeout_in_sec', 'cookies', 'headers', 'http_credentials',
                             'viewport', 'referer']
-            result: PlaywrightCaptureResponse = {}
+            result: CaptureResponse = {}
             to_capture: CaptureSettings = {}
             document_as_bytes = b''
             try:
@@ -451,7 +448,7 @@ class LacusCore():
                         try:
                             ips_info = socket.getaddrinfo(splitted_url.hostname, None, proto=socket.IPPROTO_TCP)
                         except socket.gaierror:
-                            self.logger.info(f'Unable to resolve {splitted_url.hostname}.')
+                            self.logger.debug(f'Unable to resolve {splitted_url.hostname}.')
                             result = {'error': f'Unable to resolve {splitted_url.hostname}.'}
                             raise RetryCapture
                         except Exception as e:
@@ -477,7 +474,7 @@ class LacusCore():
                     browser_engine = 'webkit'
 
             try:
-                self.logger.info(f'Capturing {url}')
+                self.logger.debug(f'Capturing {url}')
                 async with Capture(browser=browser_engine,
                                    device_name=to_capture.get('device_name'),
                                    proxy=proxy,
@@ -488,14 +485,19 @@ class LacusCore():
                     capture.viewport = to_capture.get('viewport')  # type: ignore
                     capture.user_agent = to_capture.get('user_agent')  # type: ignore
                     await capture.initialize_context()
-                    result = await capture.capture_page(
+                    playwright_result = await capture.capture_page(
                         url, referer=to_capture.get('referer'),
                         depth=to_capture.get('depth', 0),
                         rendered_hostname_only=to_capture.get('rendered_hostname_only', True))
+                    result = cast(CaptureResponse, playwright_result)
             except PlaywrightCaptureException as e:
                 self.logger.exception(f'Invalid parameters for the capture of {url} - {e}')
                 result = {'error': 'Invalid parameters for the capture of {url} - {e}'}
                 raise CaptureError
+            except asyncio.CancelledError:
+                self.logger.warning(f'The capture of {url} has been cancelled.')
+                result = {'error': f'The capture of {url} has been cancelled.'}
+                raise CaptureError
             except Exception as e:
                 self.logger.exception(f'Something went poorly {url} - {e}')
                 result = {'error': f'Something went poorly {url} - {e}'}
@@ -512,9 +514,14 @@ class LacusCore():
             else:
                 self.redis.decr(f'lacus:capture_retry:{uuid}')
             if current_retry is None or int(current_retry.decode()) > 0:
+                self.logger.info(f'Retrying {url} - {uuid}')
                 # Just wait a little bit before retrying, expecially if it is the only capture in the queue
                 await asyncio.sleep(5)
                 retry = True
+            else:
+                error_msg = result['error'] if result.get('error') else 'Unknown error'
+                self.logger.warning(f'Retried too many times {url} - {uuid}: {error_msg}')
+
         except CaptureError:
             if not result:
                 result = {'error': "No result key, shouldn't happen"}
@@ -524,7 +531,12 @@ class LacusCore():
             else:
                 self.logger.warning(f'Unable to capture {uuid}: {result["error"]}')
         else:
-            self.logger.info(f'Successfully captured {url} - {uuid}')
+            if (start_time := self.redis.zscore('lacus:ongoing', uuid)) is not None:
+                runtime = time.time() - start_time
+                self.logger.info(f'Successfully captured {url} - {uuid} - Runtime: {runtime}s')
+                result['runtime'] = runtime
+            else:
+                self.logger.info(f'Successfully captured {url} - {uuid}')
         finally:
 
             if to_capture.get('document'):
